@@ -1,4 +1,3 @@
-
 import React, { Component } from "react";
 import Overridable from "react-overridable";
 import { Message } from "semantic-ui-react";
@@ -6,8 +5,6 @@ import PropTypes from "prop-types";
 import { i18next } from "@translations/invenio_requests/i18next";
 
 class Error extends Component {
-
-
   render() {
     const { children, error, errorInfo } = this.props;
     if (error) {
@@ -31,12 +28,12 @@ class Error extends Component {
 Error.propTypes = {
   error: PropTypes.object,
   errorInfo: PropTypes.string,
-  children: PropTypes.node
+  children: PropTypes.node,
 };
 
 Error.defaultProps = {
   error: null,
-  children: null
+  children: null,
 };
 
 export default Overridable.component("Error", Error);
