@@ -10,7 +10,7 @@
 
 """RequestEvents Service."""
 
-from invenio_access.permissions import system_process
+from invenio_access.permissions import system_identity, system_user_id
 from invenio_i18n import _
 from invenio_records_resources.services import RecordService, ServiceSchemaWrapper
 from invenio_records_resources.services.base.links import LinksTemplate
@@ -40,7 +40,16 @@ class RequestEventsService(RecordService):
         return [EntityResolverExpandableField("created_by")]
 
     @unit_of_work()
-    def create(self, identity, request_id, data, event_type, uow=None, expand=False):
+    def create(
+        self,
+        identity,
+        request_id,
+        data,
+        event_type,
+        uow=None,
+        expand=False,
+        notify=True,
+    ):
         """Create a request event.
 
         :param request_id: Identifier of the request (data-layer id).
@@ -218,7 +227,7 @@ class RequestEventsService(RecordService):
 
     def _get_creator(self, identity):
         """Get the creator dict from the identity."""
-        if system_process in identity.provides:
-            return None  # TODO: Change this for some agreed value
+        if identity == system_identity:
+            return {"user": str(system_user_id)}
         else:
             return {"user": str(identity.id)}
